# tensorflow

!!! warning

    **Additional Dependencies**: To use the Tensorflow iterator, you will need to
    install additional dependencies. These dependencies are optional, as they can
    be heavy and may not be needed in all use cases. To install them, run:

    ```bash
    pip install "audioclass[tensorflow]"
    ```


::: audioclass.batch.tensorflow
